pub struct SystemObjectVersions { /* private fields */ }Implementations
Sourceimpl SystemObjectVersions
impl SystemObjectVersions
Sourcepub fn from_effects(
effects: &TransactionEffects,
store: &dyn ObjectStore,
) -> Self
pub fn from_effects( effects: &TransactionEffects, store: &dyn ObjectStore, ) -> Self
Obtains pinned system object versions from effects, queries the store for the initial shared versions.
Sourcepub fn from_latest_in_store(store: &dyn ObjectStore) -> Self
pub fn from_latest_in_store(store: &dyn ObjectStore) -> Self
Before execution, get the latest versions of the implicitly read system objects from the store, and use these versions as the exact version to read during execution. This is used only in environments where there is no consensus to assign versions, e.g. simulacrum and dry-run.